@@ -337,7 +337,7 @@ class _eintr_func_wrapper(object):
 			try:
 				rval = self._func(*args, **kwargs)
 				break
-			except OSError as e:
+			except EnvironmentError as e:
 				if e.errno != errno.EINTR:
 					raise
 
@@ -515,7 +515,7 @@ def abssymlink(symlink, target=None):
 
 _doebuild_manifest_exempt_depend = 0
 
-_testing_eapis = frozenset(["4-python", "4-slot-abi", "5-progress", "5-hdepend"])
+_testing_eapis = frozenset(["4-python", "4-slot-abi", "5-progress", "5-hdepend", "6_pre1"])
 _deprecated_eapis = frozenset(["4_pre1", "3_pre2", "3_pre1", "5_pre1", "5_pre2"])
 _supported_eapis = frozenset([str(x) for x in range(portage.const.EAPI + 1)] + list(_testing_eapis) + list(_deprecated_eapis))
 
